@@ -10,25 +10,25 @@ riceProdPhil$cost <- riceProdPhil$LABOR * riceProdPhil$LABORP +
 ## front41Data
 a1 <- sfa( log( output ) ~ log( capital ) + log( labour ),
    ineffDecrease = FALSE, data = front41Data )
-summary( a1 )
+summary( a1, farrell = FALSE )
 lrtest( a1 )
 
 ## front41Data, truncNorm
 a2 <- sfa( log( output ) ~ log( capital ) + log( labour ),
    ineffDecrease = FALSE, truncNorm = TRUE, data = front41Data )
-summary( a2 )
+summary( a2, farrell = FALSE )
 lrtest( a2 )
 
 ## riceProdPhil
 b1 <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ),
    ineffDecrease = FALSE, data = riceProdPhil )
-summary( b1 )
+summary( b1, farrell = FALSE )
 lrtest( b1 )
 
 ## riceProdPhil, truncNorm
 b2 <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ),
    ineffDecrease = FALSE, truncNorm = TRUE, data = riceProdPhil )
-summary( b2 )
+summary( b2, farrell = FALSE )
 lrtest( b2 )
 
 
